# Theme Color Generator

based on [base-16](https://github.com/chriskempson/base16) and
[arbennett/jupyterlab-themes](https://github.com/arbennett/jupyterlab-themes)

## Prerequisites

- `sass`

## Use

1. Copy `.scss` file and update with desired color hex codes
1. Run `gen_scss.sh` to convert base-16 hexes into broader list
1. Open `variables.css` and copy outputs into working theme.css file
